@@ -10,9 +10,9 @@ if sys.version_info < (2, 7):  # pragma: no cover
 
 from collections import namedtuple  # noqa
 
-__version__ = '4.6.1'
+__version__ = '4.6.3'
 __author__ = 'Ask Solem'
-__contact__ = 'ask@celeryproject.org'
+__contact__ = 'auvipy@gmail.com, ask@celeryproject.org'
 __homepage__ = 'https://kombu.readthedocs.io'
 __docformat__ = 'restructuredtext en'
 
