@@ -4,7 +4,7 @@ from kombu.asynchronous import get_event_loop
 
 from .base import Request, Headers, Response
 
-__all__ = ['Client', 'Headers', 'Response', 'Request']
+__all__ = ('Client', 'Headers', 'Response', 'Request')
 
 
 def Client(hub=None, **kwargs):
